@@ -26,6 +26,34 @@ class CkafkaClient(AbstractClient):
     _service = 'ckafka'
 
 
+    def BatchCreateAcl(self, request):
+        """This API is used to create ACL policies in batches.
+
+        :param request: Request instance for BatchCreateAcl.
+        :type request: :class:`tencentcloud.ckafka.v20190819.models.BatchCreateAclRequest`
+        :rtype: :class:`tencentcloud.ckafka.v20190819.models.BatchCreateAclResponse`
+
+        """
+        try:
+            params = request._serialize()
+            body = self.call("BatchCreateAcl", params)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.BatchCreateAclResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def CreateAcl(self, request):
         """This API is used to add an ACL policy.
 
